@@ -5,7 +5,7 @@ from nwon_django_toolbox.admin.model_admin_with_json_editor import (
     PolymorphicParentModelAdminWithJsonEditor,
 )
 from nwon_django_toolbox.admin.read_only_admin_mixin import (
-    DeletaAndReadOnlyAdminMixin,
+    DeleteAndReadOnlyAdminMixin,
     ReadOnlyAdminMixin,
 )
 from nwon_django_toolbox.admin.read_only_inline import (
