@@ -2,6 +2,7 @@ from typing import Type, Union
 
 from django.db.models import Model
 from django.urls import reverse
+from django.urls.exceptions import NoReverseMatch
 
 
 def detail_url_for_model(model: Model, primary_key: Union[str, int, None] = None):
@@ -12,10 +13,21 @@ def detail_url_for_model(model: Model, primary_key: Union[str, int, None] = None
 def detail_url_for_model_class(model: Type[Model], primary_key: Union[str, int]):
     view_name = _base_name_from_model_class(model) + "-detail"
 
-    url = reverse(
-        viewname=view_name,
-        kwargs={"pk": primary_key},
-    )
+    try:
+        url = reverse(
+            viewname=view_name,
+            kwargs={"pk": primary_key},
+        )
+    except NoReverseMatch as exception:
+        """
+        Pretty project specific workaround to make this work with a custom user model
+        named CustomUser
+        """
+        if view_name == "customuser-detail":
+            return f"/users/{primary_key}/"
+
+        raise exception
+
     return url
 
 
